![image](http://f.cl.ly/items/1F0y2N1W3V1M1v2m2k1C/wdtuts-logo.png)

#Website Launch Checklist

At [FHOKE](http://www.fhoke.com) we’ve been through it all, from perfect launches to ones that have turned into complete nightmares! Through our experiences we’ve compiled a list, in no particular order, of a process we go through before we launch our sites. 

This won’t cover everything, but should give you a quick overview of what you could be doing or adding to your own checklist.

***

##Successful Launch

After having invested a lot of time in a project, launch day will be in sight. Before you get there you’ll still have important issues that need addressing to achieve a successful launch, get these right and both you and your client will be happy.

Remember, before you show anything to a client make sure the site matches the original spec, is pixel perfect to the designs you presented and fulfills their original brief.

***

##Content

Get a small team together and go over the content of the site with a fine tooth comb - **make sure you get this right**. Good content is the cornerstone of a great site.

- **Spelling**: Check and check again. Run a spell check. Better still, get others involved. You can never have enough people making sure copy is correct. Look out for grammatical errors as well as checking for widows or orphaned words in important paragraphs.
- **Copy**: Make sure real copy is in place and all placeholder text is removed. There is nothing worse than seeing lorem ipsum in a mission statement.
- **Contact Details**: It seems obvious but make sure these are correct. Without them how do you expect people to get in touch? Check phone numbers, check email addresses and test that these are working, make a call or send an email and check they are received.
- **Copyright**: If you plan on using a date in the copyright info make sure it is set to automatically refresh from the time stamp on the server, and that the copyright owner is correct.  
- **Terms**: If you are providing a service or are involved in promotions then you will need terms available for visitors to read. If you are unsure as to how these should be written then consult a lawyer for best advice. Remember: *make these as clear as possible*. There is nothing worse than being baffled by legal jargon.
- **Privacy**: If you use cookies, capture data, or distribute data, then you need a privacy policy. Keep these simple and be clear on what data you collect and provide details of how you can be contacted for further information.
***
##Functionality
Does it work? This might seem an obvious question to ask, but above all else this is the most important part of a project. You might have everything else in place but if the site doesn't work correctly what’s the point in launching it?

Minor bugs may appear when visitors use the site for the first time but making sure it works at near 100% will ensure a successful launch.

- **Compatability**: Check the site works across all browsers and platforms. Specify at the beginning of a project to the client what platforms you will build and test to and stick to these. Use platforms such as [Responsivator](http://dfcb.github.com/Responsivator/) and [BrowserStack](http://www.browserstack.com/) to test sites quickly as well as on physical browsers and devices.
- **Favicon**: Obvious, but this can be missed. Look at creating an iOS home screen icon too.
- **Logo**: Does the logo link to the index page?
- **404 Pages**: Check you have these in place, make sure they signpost ways for a user to get back into the site or direct them to pages of interest with relevant links.
- **Redirects**: If you are redirecting pages use suitable 301 re-directs over 302.
- **Forms**: Make sure they aren’t sending to spam mail boxes, or returning an error once submitted and include a thank you state once a form is submitted so a visitor knows it is sent. Above all else make sure the clients email address is specified when the site goes live.
- **Links**: Do internal page links work? Do all external links work and do they open in a new tab if so intended?
- **RSS Feeds**: Feeds can be useful. You don’t have to limit these to articles, you can have feeds for most pages for example new work or case studies added to a site.
***
##Standards &amp; Validation 
These two things should be considered throughout the design and build to make every users experience on your site as good as it can be. Points to consider:

- **Accessibility**: It's easy to forget how inaccessible a webpage is for some users. Have you considered how assistive technologies [such as screenreaders](http://webdesign.tutsplus.com/articles/general/accessibility-whats-your-markup-saying-to-you/) will navigate your site? Have you implemented [WIA-ARIA](http://en.wikipedia.org/wiki/WAI-ARIA) roles and states, or at least considered the tab order of form controls?
- **Contrast**: This follows on from our point about accessibility. Using the very latest monitors it’s easy to see subtle differences in color, be sure to test your site on multiple devices and laptops to make sure the design has clarity and text can be read with ease.
- **Text Size**: Make text clear and easy to read, adjust line spacing and allow plenty of white space. Bigger, can mean better, when it comes to text on the web.
- **Alt Tags**: Make sure all images have clear descriptive ALT tags for the visually impaired. Not only that but without them they can’t be found in search engines.
- **Consistency**: Make sure common elements across the site are consistent to avoid confusing your users. Make buttons look like buttons, links look like links, and titles and text should be the consistent in size and color.
- **Device Compatibility**: Consider how the website will be used across multiple devices, responsive or not your website should work for desktop and mobile web users.
- **Validation**: Always aim for 100% validity. If your site fails to validate fully don’t get too upset, but be sure to understand any errors in order to to eliminate any unwanted issues.
- **JavaScript**: Many people browsing the web have JavaScript turned off for security reasons. Make sure your site is fully functional and forms still perform server-side validation checks without it.
- **Flash**: Yeah, we know, nobody uses Flash anymore right? If Flash has to be used, be sure to include an alternative backup image should Flash Player not be installed. 
***
##Sitemaps
Make sure you include sitemaps. These help search engines correctly index your website during the crawling process.

- **HTML Sitemaps**: Although not as common practice as they were, this form of sitemap can have its benefits in helping visitors see a complete overview of the sites pages. Links for these are normally found in the footer of a site. 
- **XML Sitemaps**: These are only ever used by search engines such as Google, Bing and Yahoo. Create an [XML Sitemap](http://webdesign.tutsplus.com/articles/general/all-you-need-to-know-about-xml-sitemaps/) easily and submit it via Webmaster Tools. These will then be used to inform search engines about the pages you have published.
***
##Performance
A faster site is a better ranking site. You’ll also lower bounce rates on pages if you can reduce load times - who wants to wait for pages to load?

- **Check site speed**: You can use services such as [Google Page Speed](https://developers.google.com/speed/pagespeed/) or [Blame Stella](https://www.blamestella.com/) to check the load times of your site's pages.
- **Image sizes**: Keep your images as small as possible. Although network speeds are better than ever, no one wants to wait for a 10Mb page to load. Compressing images will only improve page load times.
***
##SEO
Great SEO will mean your site will work harder and achieve greater success than a site that uses little or bad techniques. Get your research right and the rest will fall into place.

This list is by no means extensive and if you want to learn more then we recommend reading more from these recent articles [Search Engine Optimization FAQ](http://webdesign.tutsplus.com/articles/general/search-engine-optimization-faq/) and [A Web Designer’s SEO Checklist](http://webdesign.tutsplus.com/articles/general/seo-checklist/?search_index=3).

- **Keyword Research**: Make sure you are targeting the right demographic and market. It’s important to get this right in order to attract relevant traffic to your site. Carry out some research with [Google AdWords](http://www.google.co.uk/AdWords) and see which keyword (or search term) has the highest traffic potential and the least amount of competition and balance these two factors.
- **Page Titles & Descriptions**: Do all the templates have the necessary page titles and meta data based on your keyword research? When focusing on a particular keyword try and get these to the front of descriptions and look at using both singular and plural forms.
- **Image Alt-tags**: Do the main images of the site contain relevant and descriptive alt-tags? Using short descriptions will help. And remember try and choose a descriptive file name instead of random words and numbers for these images.
- **Keywords**: Embed these in titles, descriptions and copy. 
- **Content**: If the content is good it will work to optimize and compliment the SEO. Good keyword density within the copy works well so use both singular and plural forms of keywords in your text. Don’t overload the content or over think this, make it natural and only add when and if it is relevant. Search engines also prefer longer pages of content so look at getting the content to +300 words but focus more on the quality than quantity.
- **URLs**: Make sure the site's URLs are clean. Using a descriptive URL instead of ones that are made up of random numbers or words will help with SEO and visitors finding a page they may want to return to, and look at getting a keyword into the URL if relevant.
***
##Analytics
No matter how small a site is, having web analytics running will gather you valuable information on how to improve your website going forward..

- **Monitoring**: With good SEO in place use tracking codes to measure this. Tools such as [Google Analytics](http://www.google.co.uk/analytics/) (free) or services such as [Hubspot](http://www.hubspot.com/), [GoSquared](https://www.gosquared.com/) or [KISSmetrics](https://www.kissmetrics.com/) (paid) will give valuable feedback.
***
##Security
You may have a lot of things you do not want the world to know about. For example; user-uploaded media, or shoppers' Credit Card details.

- **Protect Sensitive Pages**: Protect any sensitive pages or folders from being indexed on search engines by putting in place robots.txt files and by excluding them from within Webmaster Tools. Also consider whether you need to use an .htaccess file to disable folder view within directories.
- **Security Certificates**: When developing an eCommerce website, or a site that handles sensitive visitor information, the level of security will be paramount. Make sure to use protocols such as [SSL encryption](http://www.thawte.com/) to protect against unwanted information theft. It has also been proven that displaying seals such as [TRUSTe](http://www.truste.com/products-and-services/enterprise-privacy/TRUSTed-websites), can increase the credibility of a site.
***
##Hosting &amp; Backups
Finding a web hosting provider can be hard and knowing what you need can be even harder to understand. There are many options and pricing plans to choose from but make sure to choose a provider that meets your needs, not one that offers more than you need to pay for.

- **Types**: Shared Hosting, Reseller Hosting, Cloud Hosting, VPS Hosting and Dedicated Servers. Not sure what these mean? Then read these [quick tips](http://webdesign.tutsplus.com/articles/general/quick-tip-choose-a-hosting-provider-based-on-your-needs/?search_index=1).
- **Backups**: Make sure you use a provider who can provide daily and weekly backups of your server and make sure to take local backups as well. 
- **Monitoring**: Setup services such as [Pingdom](https://www.pingdom.com/) or other server monitoring tools to monitor the health of your server.
***
##Legal
Before you start any project a signed contract should be in place. The contract should clearly outline the project deliverables and processes so both parties are 100% clear on what will be achieved as an end result. As part of that contract make sure the following has been agreed to cover any unforeseen circumstances.

- **Image/Content Rights**: Clearly state that any supplied content or imagery that is handled by you remains the clients responsibility. Make clear that you will not be held liable for publishing content and images that they do not have the rights to use. Also educate the client that they should be using images or content that are either paid for or they have the rights to use.
- **Payment Terms**: Set fair and staged payment terms at clearly defined milestones of a project (at the end of the design phase - before any development starts for example), never move on to the next phase of a project until the agreed payment is in.
- **Timelines**: Set reasonable timelines that are fair to your client as well as manageable for you and your team. Clearly state that you will not be held responsible for any loss or damages as a result of a delay in the schedule caused by the client. It is a good idea to use something like [Basecamp](http://basecamp.com/) to manage your projects so all work and conversations are recorded should you need them to fall back on in the future.
- **Intellectual Property Rights**: This will be different depending on who you are, what you’re offering, or the project in question. Clearly state what is owned by you and the client once the project is complete and payment has been made in full. Consider the rights to any software or code written by you that you wouldn’t want sold on, or anything similar that you feel you need to retain the rights to.
***
##Deliverables
In the project contract clearly explain what the client will physically receive once a project is complete. The following is what we’d recommend.

- **Live Website**: This is the bare minimum. Make sure their website is up and live and fully functioning as intended.
- **Style Guide**: A simple style guide is extremely beneficial for any website owner, points to consider include:

	+ Font Styles
	+ Image Sizes
	+ Tone of Voice
	+ Colours
	+ Imagery Style
	+ Colours

- **Assets & Icons**: Any icons, illustrations, or infographics design and created for the website may be helpful to your client going forward. Supply them the files in different formats so they can use them in presentations or future design work. 
- **Offline Copy**: If requested by the client provide a copy of the site. Remember websites are a living document that should be continually updated and improved, so unless the site is static you will have to be making regular offline backups for the client.
***
##When to Launch?
Remember: never hand over a project or files without sign off and any outstanding payments settled. You will have no come back at this point if you do without either of these. Handing over a project without payment is the equivalent of a shop owner letting a customer walk out of a shop with a trolley full of goods on the promise that they will ‘pay you later’.

Now everything is in place you are ready to launch. But when should you? We try our very best to never launch a site within two days of a weekend. Sometimes this practice has to go out the window on occasions but we always try and aim for a Monday to Wednesday launch slot. This will give you the opportunity to iron out any live bugs that surface during a working week. Trying to fix these during a weekend when either you or your developers are not around will only cause you headaches when you have a client who needs their site to be fully functional. Trust us, you will only learn the hard way if you don’t adopt this approach.

***
##Ongoing Maintenance
So you’ve launched the site, it’s working great and the client is happy, now what? You need to make sure that it continues to run without a hitch. Things can go wrong or get missed, server security compromised, or it could fall over. Make sure you’re ready for every eventuality.

- **Backups**: Always, always, make sure backups are in place. Run at least two backups daily - one in the morning and one 12 hours later, limiting the amount of data that can go missing. 
- **Version Control**: Try running a project through [Git](http://git-scm.com/), it’s a great version control system for teams of developers working in collaboration. Source code history is saved meaning that you can refer or revert back to previous versions if and when needed. For an introduction to Git read this in-depth article [Easy Version Control with Git](http://net.tutsplus.com/tutorials/other/easy-version-control-with-git/).
- **Analytics**: In order to suggest improvements going forwards ask to be set up on the client's analytics, this way you can monitor traffic and site stats for the client and suggest improvements over the following month and year after launch.

***
Let us know your launch checklist recommendations [on Webdesigntuts+](http://enva.to/XpDQqR)
